# Examples

These examples showcase how superintendent can work for you.

.. toctree::
   :maxdepth: 2

   Labelling text <labelling-text.ipynb>
   Labelling images <labelling-images.ipynb>
   Labelling images with active learning <labelling-images-actively.ipynb>
   Custom pre-processing steps as part of superintendent <preprocessing-data.ipynb>